<?php
/**
 * Onlister functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package onlister
 */

if ( !function_exists( 'onlister_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
function onlister_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on onlister, use a find and replace
	 * to change 'onlister' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'onlister', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in three locations.
	register_nav_menus( array(
		'primary'   => esc_html__( 'Primary Menu', 'onlister' ),
		'secondary' => esc_html__( 'Secondary Above Heading', 'onlister' ), 
		'footer'    => esc_html__( 'Footer Menu', 'onlister' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

    //page background image and color support
    $defaults = array(
	   'default-color'      => '#fcfcfc',
	   'default-image'       => '',
	   'wp-head-callback'     => '_custom_background_cb',
	   'admin-head-callback'   => '',
	   'admin-preview-callback' => ''
    );
    add_theme_support( 'custom-background', $defaults );
	// Set up the WordPress core logo feature.
	add_theme_support( 'custom-logo', array(
		'height'     => 150,
		'flex-width' => true,
	) );
}
endif; // onlister_setup
add_action( 'after_setup_theme', 'onlister_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function onlister_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'onlister_content_width', 940 );
}
add_action( 'after_setup_theme', 'onlister_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function onlister_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'onlister' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'onlister' ),
		'id'            => 'footer-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'onlister' ),
		'id'            => 'footer-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'onlister' ),
		'id'            => 'footer-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'onlister_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function onlister_scripts() {
	wp_enqueue_style( 'onlister-style', get_stylesheet_uri() );
	wp_enqueue_style( 'onlister-fonts', onlister_fonts_url(), array(), null );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . 
	                  '/fonts/font-awesome.css', array(), '4.5.0' );
	wp_enqueue_script( 'onlister-navigation', 
	                    get_template_directory_uri() 
	                    . '/js/navigation.js', 
	                    array(), 
	                    '20180308', 
	                    true );
	wp_enqueue_script( 'onlister-skip-link-focus-fix', 
	                    get_template_directory_uri() . 
	                    '/js/skip-link-focus-fix.js', 
	                    array(), 
	                    '20180308', 
	                    true );
	wp_enqueue_script( 'onlister-js', 
	                    get_template_directory_uri()  
	                   . '/js/main.js', 
	                    array( 'jquery' ) );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
}
add_action( 'wp_enqueue_scripts', 'onlister_scripts' );

/**
 * Register Google Fonts
 */
function onlister_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
	 * supported by Montserrat, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$montserrat = esc_html_x( 'on', 'Montserrat font: on or off', 'onlister' );

	/* Translators: If there are characters in your language that are not
	 * supported by Libre Baskerville, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$libre_baskerville = esc_html_x( 'on', 'Glegoo font: on or off', 'onlister' );

	if ( 'off' !== $montserrat && 'off' !== $libre_baskerville ) {
		$font_families = array();

		if ( 'off' !== $montserrat ) {
			$font_families[] = 'Montserrat:400';
		}

		if ( 'off' !== $libre_baskerville ) {
			$font_families[] = 'Glegoo:400,700';
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

function onlister_custom_background_callback() {

	/* Get the background image. */
	$image = get_background_image();

	/* If there's an image, just call the normal WordPress callback. We won't do anything here. */
	if ( !empty( $image ) ) {
		_custom_background_cb();
		return;
	}

	/* Get the background color. */
	$color = get_background_color();

	/* If no background color, return. */
	if ( empty( $color ) )
		return;

	/* Use 'background' instead of 'background-color'. */
	$style = "background: #{$color};";

?>
<style type="text/css">body { <?php echo trim( $style ); ?> }</style>
<?php

}
/**
 * Implementation of the Custom Header feature. (b)
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 *  @uses onlister_header_style()
 */
function onlister_custom_header_setup()
{
    add_theme_support( 'custom-header',
        apply_filters( 'onlister_custom_header_args', array(
            'default-image'          => get_template_directory_uri()
                                        . '/inc/imgs/default-header-img.png',
            'default-text-color'    => 'ffffff',
            'width'                => 1440,
            'height'              => 600,
            'flex-height'        => true,
            'flex-width'        => true,
            'wp-head-callback' => 'onlister_theme_header_style',
        ) ) );
}
add_action( 'after_setup_theme', 'onlister_custom_header_setup' );

//header elements
function onlister_theme_header_style()
{ 
    $header_text_color = get_header_textcolor();
    $header_image     = get_header_image();

    $htm = '';
    $htm .= '<style type="text/css">';
 
    if ( $header_image && ! is_paged() ) {$htm .= '#sitehead{background-image: url(' . esc_url( $header_image ) . ');background-repeat:no-repeat; z-index:1}.site-title,.site-description,.widget-title{z-index:999;color:#' . esc_attr( $header_text_color ) . '}'; 
    } 
    elseif ( $header_image && ! is_home() ) {$htm .= '#sitehead{background-image: url(' . esc_url( $header_image ) . ');background-repeat:no-repeat; z-index:1;height: 240px;}.site-title,.site-description,.widget-title{z-index:999;color:#' . esc_attr( $header_text_color ) . '}'; 
    } 
    else {$htm .= '#sitehead h4,.site-title a,.site-description,.widget-title{color:#' . esc_attr( $header_text_color ) . '}#sitehead{height: 240px}.site-header{margin-bottom:1em}.site-branding{position:relative;}#onlistSBar{top: 0;width:60%}'; 
    } 

    $htm .= '</style>';
echo $htm;
        
}

/**
 * Remove ellipsis and set read more text.
 * Dev note: Title attribute is not attribute related, 
 * it is text from the theme_mod only. Only `get_the_title` would work
 * if you want the actual title of the post.
 */
function onlister_theme_modify_read_more_link() {
    return '<a class="more-link" href="' . get_permalink() . '">... <i class="fa fa-link fa-lg"></i></a>';
}
add_filter( 'excerpt_more', 'onlister_theme_modify_read_more_link' );

/**
 * Attach a class to linked images' parent anchors
 * e.g. a img => a.img img
 */
function add_classes_to_linked_images($html) {
    $classes = 'slimbox'; // can do multiple classes, separate with space

    $patterns = array();
    $replacements = array();

    $patterns[0] = '/<a(?![^>]*class)([^>]*)>\s*<img([^>]*)>\s*<\/a>/'; // matches img tag wrapped in anchor tag where anchor tag where anchor has no existing classes
    $replacements[0] = '<a\1 class="' . $classes . '"><img\2></a>';

    $html = preg_replace($patterns, $replacements, $html);

    return $html;
}

add_filter('the_content', 'add_classes_to_linked_images', 100, 1);

/**
 * Detect plugin. For use on Front End and Back End.
 * https://developer.wordpress.org/reference/functions/is_plugin_active/
 * The following 2 functions give the (home) OnList template page
 * a custom body class @name = onlistpage
 * @uses Template `Onlist Listings Page` ! ! ! 
 */
  
// check for plugin using plugin name
function onlister_checkfor_onlist_plugin()
{
    include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    if(is_plugin_active( 'onlist/onlist.php' ) ) 
    { 
    //plugin is activated
    return true;
    }
}
//add body class if 
add_filter( 'body_class', 'onlister_addif_bodyclass_onlist' );
function onlister_addif_bodyclass_onlist($classes)
{
    $chk = onlister_checkfor_onlist_plugin();
    //check for plugin and is using template
    if($chk === true && is_page_template( 'onlist-page.php' ) ) 
    {
        $classes[] = 'onlistpage';
    }
    return $classes;
}

//generic is_page() to check for blog page.
function onlister_is_blog_page()
{
	global  $post;

	$posttype = get_post_type($post );

	return ( ((is_archive()) || (is_author()) || (is_category()) || (is_home()) || (is_single()) || (is_tag())) && ( $posttype == 'post')  ) ? true : false ;

}

//output shortcode to assigned page
function onlister_output_listings_cb()
{
if( function_exists( 'onlister_checkfor_onlist_plugin' ) ) : 
		ob_start();
		echo 
		do_shortcode("[onlist-listings]"); 
		$contents = ob_get_clean();
		return $contents;
	endif;
	return false;
}

/**
 * Jetpack setup function.
 *
 * See: https://jetpack.me/support/infinite-scroll/
 * See: https://jetpack.me/support/responsive-videos/
 */
function onlister_jetpack_setup() {
	// Add theme support for Infinite Scroll.
	add_theme_support( 'infinite-scroll', array(
		'container' => 'main',
		'render'    => 'onlister_infinite_scroll_render',
		'footer'    => 'page',
	) );

	// Add theme support for Responsive Videos.
	add_theme_support( 'jetpack-responsive-videos' );
} // end function onlister_jetpack_setup
add_action( 'after_setup_theme', 'onlister_jetpack_setup' );

/**
 * Custom render function for Infinite Scroll.
 */
function onlister_infinite_scroll_render() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/content' );
	}
} // end function onlister_infinite_scroll_render
/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
?>
