<?php
/**
 * Theme Customizer.
 *
 * @package Onlister
 *
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

 
function onlister_customize_register( $wp_customize ) {
	
	$wp_customize->add_section( 'onlister_settings_section', 
	        array(
            'title'             => __( 'Onlister Theme', 'onlister' ),
            'priority'          => 45
        ));
    // ------------------------ Settings     
    //search title setting    
    $wp_customize->add_setting( 'onlister_stitle_setting', array(
            'type'              => 'theme_mod',
            'default'           => '',
			'sanitize_callback'	=> 'sanitize_text_field'
		)
    );
    //checkbox searchbox on or off
    $wp_customize->add_setting( 'onlister_sbar_checkbox_setting', array(
            'type'              => 'theme_mod',
            'default'           => 0,
			'sanitize_callback'	=> 'onlister_sanitize_number_absint'
		)
    );
    //checkbox header image on or off
    $wp_customize->add_setting( 'onlister_headerbkg_checkbox_setting', array(
            'type'              => 'theme_mod',
            'default'           => 0,
			'sanitize_callback'	=> 'onlister_sanitize_number_absint'
		)
    );
    //checkbox sidebar on or off
    $wp_customize->add_setting( 'onlister_sidebar_checkbox_setting', array(
            'type'              => 'theme_mod',
            'default'           => 0,
			'sanitize_callback'	=> 'onlister_sanitize_number_absint'
		)
    );
    /** 
     * WP_Customize_ add_setting for anchor link color
    */
	$wp_customize->add_setting(	'onlister_anchor_color_setting', array(
            'type'              => 'theme_mod',
            'default'           => '#404040',
			'sanitize_callback'	=> 'sanitize_hex_color',
			'transport'			=> 'refresh'
		)
	);
	// Header, Footer link color
	$wp_customize->add_setting(	'onlister_headfoot_color_setting', array(
            'type'              => 'theme_mod',
            'default'           => '#e9e9e9',
			'sanitize_callback'	=> 'sanitize_hex_color',
			'transport'			=> 'refresh'
		)
	);
	
    // ------------------------ Controls
    // searchbar title
    $wp_customize->add_control(
        'onlister_search_text', array(
            'settings'          => 'onlister_stitle_setting',
            'type'              => 'text',
            'section'           => 'onlister_settings_section',
            'label'       => __( 'Wording for SearchBar in Header', 'onlister' ),
        )
    );
    //checkbox searchbar image on or off
    $wp_customize->add_control(
        'onlister_sbar_checkbox', array(
            'settings'          => 'onlister_sbar_checkbox_setting',
            'type'              => 'checkbox',
            'section'           => 'onlister_settings_section',
            'label'  => __( 'Check to Remove SearchBar in Header', 'onlister' ),
        )
    );
    //checkbox header image on or off
    $wp_customize->add_control(
        'onlister_headerbkg_checkbox', array(
            'settings'          => 'onlister_headerbkg_checkbox_setting',
            'type'              => 'checkbox',
            'section'           => 'onlister_settings_section',
            'label'       => __( 'Check to Remove Header on all but homepage and blog page.', 'onlister' ),
            'description' => __( 'Only works w/listings as Static Home Page. Home page, paged links, always show without header image. This prevents scrolling while searching listings.', 'onlister' ),
        )
    );
    //checkbox sidebar on onlistpage on or off
    $wp_customize->add_control(
        'onlister_sidebar_checkbox', array(
            'settings'          => 'onlister_sidebar_checkbox_setting',
            'type'              => 'checkbox',
            'section'           => 'onlister_settings_section',
            'label'       => __( 'Add Sidebar on Listing Page', 'onlister' ),
            'description' => __( 'Check to add sidebar. Only works when using Template Onlist Listings Page', 'onlister' ),
        )
    );
    // Anchor link color
    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'onlister_anchor_color', array(
				'settings'		=> 'onlister_anchor_color_setting',
				'section'		=> 'colors',
                'priority'      => 4,
				'label'			=> __( 'Theme Links Color', 'onlister' ),
				'description'	=> __(
                    'Select the color for the anchor links.', 'onlister' ),
			)
		)
    );
    // Header, Footer link color
    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'onlister_headfoot_color', array(
				'settings'		=> 'onlister_headfoot_color_setting',
				'section'		=> 'colors',
                'priority'      => 5,
				'label'			=> __( 'Theme Head/Foot Background', 'onlister' ),
				'description'	=> __(
                    'Select background color to Header and Footer.', 'onlister' ),
			)
		)
    );
    
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
	
}
add_action( 'customize_register', 'onlister_customize_register' );

/**
 * Theme mods for inline styles.
 * $id = onlister-customizer-css
 * @uses get_header_image in functions for header background    
*/
//css to head. PSR ignored for inline code
function onlister_theme_customizer_css() {

if ( get_theme_mods() ) : 
//emergency defaults
$onlister_primary    = "#404040";
$onlister_headerbkg = 0;
$onlister_headfoot = "#e9e9e9";
$onlister_sidebar = 0;
$onlister_sbar   = 0;
//search bar
if ( get_theme_mod( 'onlister_sbar_checkbox_setting' ) ) 
    $onlister_sbar = get_theme_mod( 
    'onlister_sbar_checkbox_setting', 0 ); 
//onlistpage sidebar    
if ( get_theme_mod( 'onlister_sidebar_checkbox_setting' ) ) 
    $onlister_sidebar = get_theme_mod( 
    'onlister_sidebar_checkbox_setting', 0 ); 
//link colors
if ( get_theme_mod( 'onlister_anchor_color_setting' ) ) 
    $onlister_primary = get_theme_mod( 
    'onlister_anchor_color_setting', '#404040' ); 
//header footer background
if ( get_theme_mod( 'onlister_headfoot_color_setting' ) ) 
    $onlister_headfoot = get_theme_mod( 
    'onlister_headfoot_color_setting', '#e9e9e9' ); 
//image background     
if ( get_theme_mod( 'onlister_headerbkg_checkbox_setting' ) ) 
    $onlister_headerbkg = get_theme_mod( 
    'onlister_headerbkg_checkbox_setting', 0 );  

    // inline styles to head
    $output = '';    
    $output .= '<style type="text/css" id="onlister-customizer-css">.main-navigation a, a, li.menu-item a, a:not(.excerpt-paragraph),a:not(.site-title a){color:' . $onlister_primary . '}.main-navigation a:visited{opacity: .8; color:' . $onlister_primary . '}#sitehead.heading-image,.site-footer{background-color:' . $onlister_headfoot . '}';
    // add only if $sbar checked
    if($onlister_sbar == 1 ) {     
        $output .= '#onlistSBar{display:none}'; 
    }
    
   if( $onlister_headerbkg == 1 ) { 
   //$header_text_color = get_header_textcolor();
    //$header_image     = get_header_image();

        if( !is_home() || is_paged() ) { 
        $output .= 'body:not(.home) #sitehead{background-image: none!important;height: 240px}.site-header{margin-bottom:1em}#onlistSBar{display: block}body.onlistpage .site-content{margin-top: 30px;padding-top:100px}';
        }
    } 
           
    if( $onlister_sidebar == 1 ) {
        $output .= 'body.page.onlistpage #primary.content-area.onlister{width: 70%;}';
        } else { 
        $output .= 'body.page.onlistpage #primary.content-area.onlister{width: 100%;}'; 
    } 
    $output .= '</style>';

    echo $output; 
endif; 
}

add_action( 'wp_head', 'onlister_theme_customizer_css' );

    
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function onlister_customize_preview_js() {
	wp_enqueue_script( 'onlister_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20180313', true );
}
add_action( 'customize_preview_init', 'onlist_customize_preview_js' ); 


//sanitizer for integer
function onlister_sanitize_number_absint( $number, $setting ) {
  // Ensure $number is an absolute integer (whole number, zero or greater).
  $number = absint( $number );

  // If the input is an absolute integer, return it; otherwise, return the default
  return ( $number ? $number : $setting->default );
}

